#########################################################################################################
# Analysis for the paper Computer-based perspective broadening Support for appraisal Training - Study 1
# 2017, 2018 TUDelft
# Output file "output-study1.txt" will be created 
#
# required datafiles
# - study1_Biodata.csv
# - study1_Q1.csv
# - study1_Q2.csv 
# - study1_behav.csv
#########################################################################################################

#adjust this to folder that contain data files
setwd("~/surfdrive/research/Ursula/Effectstudy/")

## capture all the output to a file.

sink("output-study1.txt")
sessionInfo()

########### libraries
library(gmodels)
library(Hmisc)
library(car)
###########


################################################# Data ##########################################################################
#
##### study1_Biodata.csv
# This file contains biographic data of the participants of study 1
#
#
# data fields
#
#1 Profession: 0 -> soldier, 1 -> firefighter
#2 Age: age in years
#3 Gender : 0 -> male, 1 -> female

Biostudy1 <-read.csv("study1_Biodata.csv", header=TRUE,  sep = ",")
Biostudy1$Profession <- factor(Biostudy1$Profession, levels = c(0:1), labels = c("soldier", "firefighter"))
Biostudy1$Gender <- factor(Biostudy1$Gender, levels = c(0:1), labels = c("male", "female"))


## study1_Q1.csv   File with data from the first questionnaire
#
# data fields
#
#1 ID       : id number
#2 Profession: Profession: 0 -> soldier, 1 -> firefighter
#3 Date     : date of workshop and data was collected
#4 ALG_1    : question "I found the four themes useful" strongly disagree, disagree, neutral, agree, to strongly agree
#5 ALG_2    : question "I found labeling the videos a useful exercise to become familiar with the themes" strongly disagree, disagree, neutral, agree, to strongly agree
#6 ALG_3    : questions "The video labeling exercises will help me to see possible future disturbing situations from a different perspective" strongly disagree, disagree, neutral, agree, to strongly agree
#7 V_1      : question "The content of video 1 ([video title here]) was disturbing" strongly disagree, disagree, neutral, agree, to strongly agree
#8 V_2      : question "The content of video 2 ([video title here]) was disturbing" strongly disagree, disagree, neutral, agree, to strongly agree
#9 V_3      : question "The content of video 3 ([video title here]) was disturbing" strongly disagree, disagree, neutral, agree, to strongly agree
#10 VSP1_1   : question "I first watched the entire video before I started labeling" (yes/no) Full annotation version
#11 VSP1_2  : question "The labeling distracted me from watching the video" (strongly disagree, disagree, neutral, agree, strongly agree) Full annotation version
#12 VSP1_3  : question "I found this version of the labeling tool easy to use" (strongly disagree, disagree, neutral, agree, strongly agree) Full annotation version
#13 VSP2_1  : question "I found this version of the labeling tool easy to use" (strongly disagree, disagree, neutral, agree, strongly agree) Labeling after version
#14 VSP3_1  : question "The labeling distracted me from watching the video" (strongly disagree, disagree, neutral, agree, strongly agree) Real-time labeling version
#15 VSP3_2  : question "I was able to label and watch the video" (strongly disagree, disagree, neutral, agree, strongly agree) Real-time labeling version
#16 VSP3_3  : question "I found this version of the labeling tool easy to use" (strongly disagree, disagree, neutral, agree, strongly agree) Real-time labeling version
#17 Best_VSP : question "Which of the labeling tools did you find best to help learn the themes?"
#18 VSP1_Difficulty: rating for Full annotation version (question Please number the tools in order of easiest exercise to most difficult, rate from 1 - easiest, 2 - middle, 3 - most difficult)"
#19 VSP2_Difficulty: rating for Labeling after version (question Please number the tools in order of easiest exercise to most difficult, rate from 1 - easiest, 2 - middle, 3 - most difficult)"
#20 VSP3_difficulty: rating for Real-time labeling version (question Please number the tools in order of easiest exercise to most difficult, rate from 1 - easiest, 2 - middle, 3 - most difficult)"
#21 Remark : Remark in dutch

Q1data <- read.csv("study1_Q1.csv", header=TRUE,  sep = ",")
Q1data$Profession <- factor(Q1data$Profession, levels = c(0:1), labels = c("soldier", "firefighter"))



## study1_Q2.csv   File with data from the second questionnaire
#
# data fields
#
#1 ID       : id number
#2 Profession:  1 -> soldier, 2 -> firefighter
#3 D1 : question "After completing this workshop I can assess whether this strategy suits me"  (strongly disagree, disagree, neutral, agree, strongly agree)
#4 D2 : question "After completing this workshop I have gained experience with applying this strategy" (strongly disagree, disagree, neutral, agree, strongly agree)
#5 D3 : question "After completing this workshop I understand the benefits/added value of this strategy" (strongly disagree, disagree, neutral, agree, strongly agree)
#6 D4 : question "After completing this workshop I was able to support others with practicing it" (strongly disagree, disagree, neutral, agree, strongly agree)
#7 L1 : question "It was fun to do this workshop"
#8 L2 : question "The workshop was educational/ the topic of the workshop is relevant to me"
#9 L3 : question "I felt actively engaged with the workshop"
#10 L4 : question "I think I master the topic of the workshop well"
#11 L5 : question "I have learned a lot from working together with others in this workshop"
#12 C1 : question "How important do you find the topic of coping?" (numerical from 1 - not at all important to 10 - very important)
#13 C2 : question "Do you want to get better at it?" (numerical from 1 - not at all important to 10 - very important)
#14 S1 : question "I usually manage to get out of difficult situations without much effort"
#15 S2 : question "I recover quickly from illnesses or setbacks" : (strongly disagree, disagree, neutral, agree, strongly agree)
#16 S3 : question "I can concentrate under pressure" : (strongly disagree, disagree, neutral, agree, strongly agree)
#17 S4 : question "Even when I am under great pressure, I remain calm" : (strongly disagree, disagree, neutral, agree, strongly agree)
#18 S5 : question "I don't need much time to recover from stressful situations" : (strongly disagree, disagree, neutral, agree, strongly agree)
#19 S6 : question "I easily pick my life back up after something bad happens" : (strongly disagree, disagree, neutral, agree, strongly agree)
#20 S7 : question "It doesn't take me much time to rise above setbacks in my life" : (strongly disagree, disagree, neutral, agree, strongly agree)
#21 S8 : question "I can handle bad feelings well" : (strongly disagree, disagree, neutral, agree, strongly agree)

Q2data <- read.csv("study1_Q2.csv", header=TRUE,  sep = ",")
Q2data$Profession <- factor(Q2data$profession, levels = c(1:2), labels = c("soldier", "firefighter"))

## study1_behav.csv   File with behavioral data collected from the interaction with annotation tool
#
# data fields
#
#1 ID       : id number
#2 Profession:  1 -> soldier, 2 -> firefighter
#3 VSP1_count_positive : number of times possive theme applied with the Full annotation version
#4 VSP1_count_meaning : number of times meaning theme applied with the Full annotation version
#5 VSP1_count_growth : number of times growth theme appliedwith the Full annotation version
#6 VSP1_count_acceptance : number of times acceptance theme applied with the Full annotation version
#7 VSP2_count_positive : number of times possive theme applied with the labelling afterwards version
#8 VSP2_count_meaning : number of times meaning theme applied with the labelling afterwards version
#9 VSP2_count_growth : number of times growth theme appliedwith the labelling afterwards version
#10 VSP2_count_acceptance : number of times acceptance theme applied with the labelling afterwards version
#11 VSP3_count_positive : number of times possive theme applied with the realtime labelling version
#12 VSP3_count_meaning : number of times meaning theme applied with the realtime labelling version
#13 VSP3_count_growth : number of times growth theme applied with the realtime labelling version
#14 VSP3_count_acceptance : number of times acceptance theme applied with the realtime labelling version
#15 VSP1_wordcount with the Full annotation version

bdata <- read.csv("study1_behav.csv", header=TRUE,  sep = ",")
bdata$Profession <- factor(bdata$profession, levels = c(1:2), labels = c("soldier", "firefighter"))


######################################################## functions ###################################

Mdn_freq_IQR <-function(s)
{
  s <- na.omit(s)
  s <- data.matrix(s)
  m <- median(s)
  fr <- length(s[s==m])
  tot <- length(s)
  rel <- fr/tot
  i <- IQR(s)
  cat("Mdn: ", m, ", freq ", rel, ", IQR ", i)
}

Check_Sample <-function(var_name, fr, var_nr)
{ # wilcox test and power analysis approximation 
  cat("\nCheck for: ", var_name, "\n")
  f <- fr
  f$dept <- f[[var_nr]]
  print(wilcox.test(dept ~ Profession, data=f))
  
  #approximate power assuming normal distribution 
  
  m1<-mean(f$dept[f$Profession == "soldier"],na.rm = TRUE)
  sd1 <- sd(f$dept[f$Profession == "soldier"],na.rm = TRUE)
  n1 <- length(f$dept[f$Profession == "soldier"])
  
  m2 <- mean(f$dept[f$Profession == "firefighter"],na.rm = TRUE)
  sd2 <- sd(f$dept[f$Profession == "firefighter"],na.rm = TRUE)
  n2 <-length(f$dept[f$Profession == "firefighter"])
  cat("soldier group: n", n1,"; mean ", m1,"; sd ", sd1, "\n")
  cat("firefighter group: n", n2,"; mean ", m2,"; sd ", sd2, "\n")
  
  pval <- replicate(10000, wilcox.test(rnorm(n1,m1,sd1), rnorm(n2,m2,sd2))$p.value)  # run 10000 simulation wilxon test with random generated data based normal distribution and n, mean and sd parameters from the real samples
  s <- sum(pval < .05) #sum number of simulated trails with sign result
  cat("\n Approximate power (alpha =.05) ", s/10000, "\n")
  
}




table1_row <- function(s,fr,vr,c=TRUE)
{
  cat("\n",s," military: ")
  m<-subset(fr,Profession=="soldier" )
  Mdn_freq_IQR(m[[vr]])
  cat("; firefighter: ")
  m<-subset(fr,Profession=="firefighter" )
  Mdn_freq_IQR(m[[vr]])
  if (c==TRUE) { 
    cat("; combinded: ")
    Mdn_freq_IQR(fr[[vr]])
  }
}


################################################## Analysis #######################################################

cat("\n################################### Section 2.1.2. Participants Bio data\n")

cat("Number of soldiers and firefighter\n")
table(Biostudy1$Profession)

cat("Experience of firefighters not included in data set\n")

cat("Difference between age of soldiers and firefighters\n")
cat("First Test if equal variance in two groups can be assumed\n")
leveneTest(Biostudy1$Age ~ Biostudy1$Profession, center=median)
cat("\nAs variance are  sign difference,  Welch Two Sample t-test conducted\n")
t.test(Biostudy1$Age ~ Biostudy1$Profession, na.action = na.exclude, var.equal = FALSE)
cat("\n SD soldier: ")
sd(Biostudy1$Age[Biostudy1$Profession == "soldier"],na.rm = TRUE)

cat(" , SD firefighters: ")
sd(Biostudy1$Age[Biostudy1$Profession == "firefighter"],na.rm = TRUE)

cat("\n\nTesting difference between soldier and firefighter data presented in table 1\n\n")
cat("\nCoping strategy: reapraisal\n")
Check_Sample("Utility", Q1data, 4)
Check_Sample("Suitability", Q2data, 3)
Check_Sample("Benefits", Q2data, 5)

cat("\n\nTools\n")
Check_Sample("Utility", Q1data,5)
Check_Sample("Experience", Q2data, 4)
Check_Sample("Future use", Q1data, 6)

cat("\n\nEase of use\n")
Check_Sample("Video player 1 (full)", Q1data, 12)
Check_Sample("Video player 2 (after)", Q1data, 13)
Check_Sample("Video player 3 (real-time)", Q1data, 16)

cat("\n\nVideo content: -how distressing - not compared as soldier and firefighters saw different videos\n")

cat("\n\nWorkshop\n")
Check_Sample("Enjoyable (to do)", Q2data, 7)
Check_Sample("Personal relevance", Q2data, 8)
Check_Sample("Active involvement", Q2data, 9)
Check_Sample("Grasp of subject", Q2data, 10)


cat("\n\n################################### Section 2.2 Analysis & results\n\n")
cat("\n\n Table 1: Military and firefighters's subjective assessment\n")

cat("\nCoping strategy: reapraisal\n")
table1_row("Utility", Q1data, 4)
table1_row("Suitability", Q2data, 3)
table1_row("Benefits", Q2data, 5)

cat("\n\nTools\n")
table1_row("Utility", Q1data,5)
table1_row("Experience", Q2data, 4)
table1_row("Future use", Q1data, 6)

cat("\n\nEase of use\n")
table1_row("Video player 1 (full)", Q1data, 12)
table1_row("Video player 2 (after)", Q1data, 13)
table1_row("Video player 3 (real-time)", Q1data, 16)

cat("\n\nVideo content: how distressing\n")
table1_row("Video 1", Q1data, 7, FALSE)
table1_row("Video 2", Q1data, 8, FALSE)
table1_row("Video 3", Q1data, 9, FALSE)

cat("\n\nWorkshop\n")
table1_row("Enjoyable (to do)", Q2data, 7)
table1_row("Personal relevance", Q2data, 8)
table1_row("Active involvement", Q2data, 9)
table1_row("Grasp of subject", Q2data, 10)



cat("\n\n\n################################### Section 2.2.1 - Primary outcome measures\n\n")
## for background on one-sample Wilcoxon signed rank test see http://rcompanion.org/handbook/F_02.html
cat("\n\n## Assessing of coping strategy\n")
cat("\nTesting whether question (ALG_1) - \"I found the four themes useful\" deviated from 3 (neutral value)\n")
wilcox.test(Q1data$ALG_1, mu=3, exact = FALSE, na.action = na.exclude)

cat("\nTesting whether question (D1) - \" I can judge whether this strategy suits me\" deviated from 3 (neutral value) \n")
wilcox.test(Q2data$D1, mu=3, exact = FALSE, na.action = na.exclude)

cat("\nTesting whether question (D3) - \" I understand the benefits of this strategy\" deviated from 3 (neutral value) \n")
wilcox.test(Q2data$D3, mu=3, exact = FALSE, na.action = na.exclude)

cat("\n\n## Assessment of tools\n")
cat("\nTesting whether question (ALG_2) - \"I found labeling the videos a useful exercise to become familiar with the themes\" deviated from 3 (neutral value)\n")
wilcox.test(Q1data$ALG_2, mu=3, exact = FALSE, na.action = na.exclude)

cat("\nTesting whether question (D2) - \"After completing this workshop I have gained experience with applying this strategy\" deviated from 3 (neutral value)\n")
wilcox.test(Q2data$D2, mu=3, exact = FALSE, na.action = na.exclude)

cat("\nTesting whether question (ALG_3) - \"The video labeling exercises will help me to see possible future disturbing situations from a different perspective\" deviated from 3 (neutral value)\n")
wilcox.test(Q1data$ALG_3, mu=3, exact = FALSE, na.action = na.exclude)

cat("\n\n## Ease of use\n")
cat("\nTesting whether question (VSP1_3) - \"I found this [Full annotation] version of the labeling tool easy to use Full annotation\" deviated from 3 (neutral value)\n")
wilcox.test(Q1data$VSP1_3, mu=3, exact = FALSE, na.action = na.exclude)

cat("\nTesting whether question (VSP2_1) - \"I found this [Labelling after] version of the labeling tool easy to use Full annotation\" deviated from 3 (neutral value)\n")
wilcox.test(Q1data$VSP2_1, mu=3, exact = FALSE, na.action = na.exclude)

cat("\nTesting whether question (VSP3_3) - \"I found this [Real-Time labeling] version of the labeling tool easy to use Full annotation\" deviated from 3 (neutral value)\n")
wilcox.test(Q1data$VSP3_3, mu=3, exact = FALSE, na.action = na.exclude)


cat("\n\n##Ranking versions on easiest to use\n")
#combining 3 rating variable into one single variable, about version rated easiest 
v1 <- Q1data$VSP1_Difficulty
v2 <- Q1data$VSP2_Difficulty
v3 <- Q1data$VSP3_difficulty


v1[v1 == 1] <- 1
v1[v1 != 1] <- 0

v2[v2 == 1] <- 1
v2[v2 != 1] <- 0

v3[v3 == 1] <- 1
v3[v3 != 1] <- 0


r <- v1*1 + v2*2 + v3*4
r <-r[r==1 | r==2 | r==4]
r <- na.omit(r)
r <-log2(r)
r <- factor(r, levels = c(0:2), labels = c("full annotation", "real-time labeling","labeling after"))
cat("Relative frequency when a version was rated as the easiest\n")
table(r)/length(r)
cat("Testing equal distribution of version labelled as easiest version\n")
chisq.test(table(r))

cat("\nTesting equal distribution when real-time version is removed\n")
r3 <- r[r!='real-time labeling']
r3 <- as.matrix(r3)
table(r3)/length(r3)
chisq.test(table(r3))

cat("\nTesting equal distribution when full annotation version is removed\n")
r1 <- r[r!='full annotation']
r1 <- as.matrix(r1)
table(r1)/length(r1)
chisq.test(table(r1))

cat("\nTesting equal distribution when labeling after version is removed\n")
r2 <- r[r!='labeling after']
r2 <- as.matrix(r2)
table(r2)/length(r2)
chisq.test(table(r2))





cat("\n\n## Distraction\n")
cat("Median rating for labelling distracted me from watching video when using full annotation version\n")
median(na.omit(Q1data$VSP1_2)) 
wilcox.test(Q1data$VSP1_2, mu=3, exact = FALSE, na.action = na.exclude)

cat("\n\n## Workshop\n")
cat("\nTesting whether question (L1) about enjoyability of workshop deviated from 3 (neutral value)\n")
wilcox.test(Q2data$L1, mu=3, exact = FALSE, na.action = na.exclude)

cat("\nTesting whether question (L2) about relevance of workshop deviated from 3 (neutral value)\n")
wilcox.test(Q2data$L2, mu=3, exact = FALSE, na.action = na.exclude)

cat("\nTesting whether question (L3) about active involvement workshop deviated from 3 (neutral value)\n")
wilcox.test(Q2data$L3, mu=3, exact = FALSE, na.action = na.exclude)

cat("\nTesting whether question (L4) about good grasp of the workshop topic deviated from 3 (neutral value)\n")
wilcox.test(Q2data$L4, mu=3, exact = FALSE, na.action = na.exclude)

cat("\n\n\n###################################Section 2.2.2 Secondary outcome measures\n\n")
cat("Tool preference")
r <- factor(Q1data$Best_VSP, levels = c(1:3), labels = c("full annotation", "real-time labeling","labeling after"))
r <- na.omit(r)
cat("Relative frequency of  version rated as best\n")
table(r)/length(r)
cat("Testing equal distribution of version labelled as best version\n")
chisq.test(table(r))

cat("\nTesting equal distribution when real-time version is removed\n")
r3 <- r[r!='real-time labeling']
r3 <- as.matrix(r3)
table(r3)/length(r3)
chisq.test(table(r3))

cat("\nTesting equal distribution when full annotation version is removed\n")
r1 <- r[r!='full annotation']
r1 <- as.matrix(r1)
table(r1)/length(r1)
chisq.test(table(r1))

cat("\nTesting equal distribution when labeling after version is removed\n")
r2 <- r[r!='labeling after']
r2 <- as.matrix(r2)
table(r2)/length(r2)
chisq.test(table(r2))

cat("\n\n### Film check\n\n")
cat("rating for video 1 (for firefighter, Crash Turkish Air)\n")
CrossTable(Q1data$V_1, Q1data$Profession, expected = FALSE, prop.r=FALSE, prop.c=TRUE, prop.t=FALSE, prop.chisq=FALSE, chisq=FALSE)

cat("Spearman correlation between video content and ease of use player used label that video\n")
rcorr(as.matrix(na.omit(data.frame(Q1data$V_1,Q1data$VSP1_3))), type = "spearman")
rcorr(as.matrix(na.omit(data.frame(Q1data$V_2,Q1data$VSP2_1))), type = "spearman")
rcorr(as.matrix(na.omit(data.frame(Q1data$V_3,Q1data$VSP3_3))), type = "spearman")

cat("\n\n###################################Section 2.2.2.3 Engagement with tools\n\n")
cat("Average number of themes used in full annotation version:",mean(na.omit(bdata$VSP1_count_positive+bdata$VSP1_count_meaning+bdata$VSP1_count_growth+bdata$VSP1_count_acceptance)))
cat("; labelling after version:",mean(na.omit(bdata$VSP2_count_positive+bdata$VSP2_count_meaning+bdata$VSP2_count_growth+bdata$VSP2_count_acceptance)))
cat("; real-time labelling version:", mean(na.omit(bdata$VSP3_count_positive+bdata$VSP3_count_meaning+bdata$VSP3_count_growth+bdata$VSP3_count_acceptance)))
cat("\n\n")

cat("Test difference in number of themes applied in full annotation version by soldiers and firefighters\n")
bdata$VSP1_them <- bdata$VSP1_count_positive+bdata$VSP1_count_meaning+bdata$VSP1_count_growth+bdata$VSP1_count_acceptance
cat("First Test if equal variance in two groups can be assumed\n")
leveneTest(VSP1_them ~ Profession, bdata, center=median)
cat("\nAs variance are not sign difference,  Two Sample t-test conducted\n")
t.test(bdata$VSP1_them ~ bdata$Profession, var.equal = TRUE)
cat("SD soldier ", sd(bdata$VSP1_them[bdata$Profession=="soldier"], na.rm = TRUE), "; firefighter ", sd(bdata$VSP1_them[bdata$Profession=="firefighter"], na.rm = TRUE),"\n")

cat("\nTest difference in total number of words written by soldiers and firefighter\n")
cat("First Test if equal variance in two groups can be assumed\n")
leveneTest(VSP1_wordcount ~ Profession, bdata, center=median)
cat("\nAs variance are  sign difference,  Welch Two Sample t-test conducted\n")
t.test(bdata$VSP1_wordcount ~ bdata$Profession, var.equal = FALSE)
cat("SD soldier ", sd(bdata$VSP1_wordcount[bdata$Profession=="soldier"], na.rm = TRUE), "; firefighter ", sd(bdata$VSP1_wordcount[bdata$Profession=="firefighter"], na.rm = TRUE), "\n")
cat("Sample size (N) soldiers ",length(na.omit(bdata$VSP1_wordcount[bdata$Profession=="soldier"])), "; firefighters ", length(na.omit(bdata$VSP1_wordcount[bdata$Profession=="firefighter"])),"\n")

cat("\n\nDid participant immediately start labelling or first watch film in full annotation version?\n")
CrossTable(Q1data$VSP1_1, Q1data$Profession, expected = TRUE, prop.r=FALSE, prop.c=TRUE, prop.t=FALSE, prop.chisq=FALSE, chisq=TRUE)
cat("\n\nIs there a correlation between starting immediately with labelling (yes/no) and number of themes applied in full annotation version ?\n")
rcorr(as.matrix(na.omit(data.frame(Q1data$VSP1_1,bdata$VSP1_them))), type = "pearson") 

cat("\n\nIs there a correlation between starting immediately with labelling (yes/no) and number of words used in full annotation version ?\n")
rcorr(as.matrix(na.omit(data.frame(Q1data$VSP1_1,bdata$VSP1_wordcount))), type = "pearson") 


cat("\n\n################################### End of analysis for study 1\n")


######### stop redireting output.
sink()

cat("\n\nOutput of the analysis can be found back in file output-study1.txt")