#########################################################################################################
# Analysis for the paper Computer-based perspective broadening Support for appraisal Training - Study 2
# 2017 TUDelft
# Output file "output-study2.txt" will be created 
#
# required datafiles
# - study2_prepost.csv 
# - study2_trainingdata.csv
# - study2_intrusion.csv
#########################################################################################################

#adjust this to folder that contain data files
setwd("~/surfdrive/research/Ursula/Effectstudy/")

## capture all the output to a file.

sink("output-study2.txt")
sessionInfo()


################################# libraries
library (foreign)
library (car)
library (ggplot2)
library (nlme)
library (reshape)
library (lattice)
library(psych)
library(MASS)
#################################

########################################################################### DATA ###################

########## study2_prepost.csv   
# File with pre and post measurement data from the second study in wide format
# Data orignally obtained from the file OneRowForOneCase_pre-post_new.csv 
#
# data fields
#
#1 ss: participant ID number
#2 gender: gender of participant, 0 = male ,1 = female 
#3 age: age of participants in years
#4 condition: experimental condition participant was assigned to, 0 =with tool, 1= without tool"
#5 film_order: 
#6 attentive_voor : Indicate how much time (in percentage) you have kept your attention with the film (0-100% scale) ([Dutch]voor/[English]before training -> pre-measurement)
#7 attentive_na : Indicate how much time (in percentage) you have kept your attention with the film (0-100% scale) ([Dutch]na/[English]after training -> post-measurement)
#8 distacted_voor :How much of the time were you distracted from the film? (for example, thinking of other things (not related to the film) while watching the film, and / or how often did you look away or did you close your eyes during the film?) (0-100% scale)
#9 distracted_na
#10 active_voor : How much of the time did you actively think about how you can look at it differently? (0-100% scale)
#11 active_na
#12 supress_voor :How much of the time did you suppress your emotions? (0-100% scale)
#13 supress_na
#14 seen_voor: Have you seen this film clip before?  0=no, 1=yes
#15 seen_na
#16 meeleven_voor :I was able to sympathize with the people in the film. 5 point scale (1 = totally disagree, 3= neutral, 5 = totally agrees)
#17 meeleven_na
#18 kijkmanier_voor : Did you at least used one theme successfully, 0 = no, 1= yes
#19 kijkmanier_na
#20 p1_voor : Positive and Negative Affect Schedule (PANAS) item - (Dutch: ge??nteresseerd/ English:interested ), 5 point likert scale from (0 Not at all, 1 A little, 2 Medium, 3 Strong, 4 Very strong)
#21 p1_na
#22 p2_voor : Positive and Negative Affect Schedule (PANAS) item - (Dutch: bedroefd/ English: distressed) 5 point likert scale from (0 Not at all, 1 A little, 2 Medium, 3 Strong, 4 Very strong) 
#23 p2_na
#24 p3_voor : Positive and Negative Affect Schedule (PANAS) item - (Dutch: opgewekt/ English: excited) 5 point likert scale from (0 Not at all, 1 A little, 2 Medium, 3 Strong, 4 Very strong) 
#25 p3_na
#26 p4_voor :Positive and Negative Affect Schedule (PANAS) item - (Dutch: verontrust/ English: upset) 5 point likert scale from (0 Not at all, 1 A little, 2 Medium, 3 Strong, 4 Very strong)
#27 p4_na
#28 p5_voor :Positive and Negative Affect Schedule (PANAS) item - (Dutch: sterk/ English: strong) 5 point likert scale from (0 Not at all, 1 A little, 2 Medium, 3 Strong, 4 Very strong)
#29 p5_na
#30 p6_voor: Positive and Negative Affect Schedule (PANAS) item - (Dutch: schuldig/ English: guilty) 5 point likert scale from (0 Not at all, 1 A little, 2 Medium, 3 Strong, 4 Very strong) 
#31 p6_na
#32 p7_voor: Positive and Negative Affect Schedule (PANAS) item - (Dutch: angstig/ English: scared) 5 point likert scale from (0 Not at all, 1 A little, 2 Medium, 3 Strong, 4 Very strong)
#33 p7_na
#34 p8_voor:  Positive and Negative Affect Schedule (PANAS) item - (Dutch: vijandig/ English: hostile) 5 point likert scale from (0 Not at all, 1 A little, 2 Medium, 3 Strong, 4 Very strong) 
#35 p8_na
#36 p9_voor : Positive and Negative Affect Schedule (PANAS) item - (Dutch: enthousiast/ English: enthousiast) 5 point likert scale from (0 Not at all, 1 A little, 2 Medium, 3 Strong, 4 Very strong) 
#37 p9_na
#38 p10_voor : Positive and Negative Affect Schedule (PANAS) item - (Dutch: zelfverzekerd/ English: proud) 5 point likert scale from (0 Not at all, 1 A little, 2 Medium, 3 Strong, 4 Very strong) 
#39 p10_na
#40 p11_voor : Positive and Negative Affect Schedule (PANAS) item - (Dutch: snel ge??rriteerd/ English: irritable) 5 point likert scale from (0 Not at all, 1 A little, 2 Medium, 3 Strong, 4 Very strong)
#41 p11_na
#42 p12_voor : Positive and Negative Affect Schedule (PANAS) item - (Dutch: alert/ English:alert) 5 point likert scale from (0 Not at all, 1 A little, 2 Medium, 3 Strong, 4 Very strong)
#43 p12_na
#44 p13_voor : Positive and Negative Affect Schedule (PANAS) item - (Dutch: beschaamd/ English: ashamed) 5 point likert scale from (0 Not at all, 1 A little, 2 Medium, 3 Strong, 4 Very strong)
#45 p13_na
#46 p14_voor :  Positive and Negative Affect Schedule (PANAS) item - (Dutch: vol inspiratie/ English: inspired) 5 point likert scale from (0 Not at all, 1 A little, 2 Medium, 3 Strong, 4 Very strong)
#47 p14_na
#48 p15_voor : Positive and Negative Affect Schedule (PANAS) item - (Dutch: gespannen/ English: nervous) 5 point likert scale from (0 Not at all, 1 A little, 2 Medium, 3 Strong, 4 Very strong) 
#49 p15_na
#50 p16_voor: Positive and Negative Affect Schedule (PANAS) item - (Dutch: vastberaden/ English: determined) 5 point likert scale from (0 Not at all, 1 A little, 2 Medium, 3 Strong, 4 Very strong)
#51 p16_na
#52 p17_voor: Positive and Negative Affect Schedule (PANAS) item - (Dutch: aandachtig/ English: attentive) 5 point likert scale from (0 Not at all, 1 A little, 2 Medium, 3 Strong, 4 Very strong)
#53 p17_na
#54 p18_voor: Positive and Negative Affect Schedule (PANAS) item - (Dutch: zenuwachtig/ English: jittery) 5 point likert scale from (0 Not at all, 1 A little, 2 Medium, 3 Strong, 4 Very strong)
#55 p18_na
#56 p19_voor: Positive and Negative Affect Schedule (PANAS) item - (Dutch: energiek/ English: active) 5 point likert scale from (0 Not at all, 1 A little, 2 Medium, 3 Strong, 4 Very strong)
#57 p19_na
#58 p20_voor: Positive and Negative Affect Schedule (PANAS) item - (Dutch: bang/ English: afraid) 5 point likert scale from (0 Not at all, 1 A little, 2 Medium, 3 Strong, 4 Very strong)
#59 p20_na
#60 PA_total_voor : summation of positive PANAS items pre measurement
#61 PA_total_na
#62 NA_total_voor : summation of negative PANAS items
#63 NA_total_na
#64 numANNOS_U_voor :Number of annotation coder U
#65 numANNOS_U_na
#66 numANNOS_C_voor :Number of annotation coder C
#67 numANNOS_C_na
#68 numANNOS_mean_voor :mean number of annotations
#69 numANNOS_mean_na
#70 Score_U :annotation score by coder U
#71 Score_C :annotation score by coder C
#72 Score_mean : mean score of annotations       
#73 intrusions:  How often have you had intrusive memories of a previous film?
#74 WCpre : wordcount
#75 WCpost

prepostwide <- read.csv("study2_prepost.csv")
# defining missing value that code as 999 in p10_voor, p19_voor and PA_total_voor 
prepostwide$p10_voor[prepostwide$p10_voor==999] <- NA 
prepostwide$p19_voor[prepostwide$p19_voor==999] <- NA 
prepostwide$PA_total_voor[prepostwide$PA_total_voor==999] <- NA 
prepostwide$intrusions[prepostwide$intrusions==999] <- NA 

#convert to factors prepostwide
prepostwide$condition <- factor(prepostwide$condition, levels = c(0,1), labels = c("with tool", "without tool"))
prepostwide$gender <- factor(prepostwide$gender, levels = c(0,1), labels = c("male", "female"))
prepostwide$seen_voor <- factor(prepostwide$seen_voor, levels = c(0,1), labels = c("no", "yes"))
prepostwide$seen_na <- factor(prepostwide$seen_na, levels = c(0,1), labels = c("no", "yes"))

#reshaping from wide format to a long format
prepostlong<-reshape(prepostwide,
        idvar = "ss",
        varying = list(attentive = c(6,7), distracted = c(8,9), active = c(10,11), supress = c(12,13), seen = c(14,15),
                       sympathize = c(16,17),  themeuse = c(18,19), p1=c(20,21), p2=c(22,23), p3=c(24,25), p4=c(26,27), 
                       p5=c(28,29), p6=c(30,31), p7=c(32,33), p8=c(34,35), p9=c(36,37), p10=c(38,39), p11=c(40,41), 
                       p12=c(42,43), p13=c(44,45), p14=c(46,47), p15=c(48,49), p16=c(50,51), p17=c(52,53), p18=c(54,55), 
                       p19=c(56,57), p20=c(58,59),PA_total = c(60,61), NA_total = c(62,63), numANNOS_U = c(64,65),
                       numANNOS_C =c(66,67), numANNOS_mean=c(68,69), wordcount = c(74,75)),
        v.names = c("attentive", "distracted","active","supress", "seen","sympathize", "themeuse",
                    "p1", "p2", "p3", "p4", "p5", "p6", "p7", "p8", "p9", "p10", "p11", "p12", "p13",
                    "p14", "p15", "p16", "p17", "p18", "p19", "p20", "PA_total", "NA_total", "numANNOS_U", "numANNOS_C",
                    "numANNOS_mean", "wordcount"),
        drop =c('Score_U','Score_C','Score_mean','intrusions','gender', 'age', 'film_order'),
        direction="long",
        times = 0:1,
        timevar = "time"
)
prepostlong$time <- factor(prepostlong$time, levels = c(0,1), labels = c("pre", "post"))

########## study2_trainingdata.csv   
# File with 6 in training measurements data from the second study in wide format
# Data was originally taken from the file MultipleRowsForOneCase_training_new.csv, but dropping variable ppID, age, gender
#
# data fields
#
#1 ss: participant ID number
#2 condition : experimental condition, 0 = with tool, 1 = without tool
#3 time : number in the sequence of 6 films
#4 numthemes : number of themes on number of themes used in training
#5 flimorder : order in which the participants watch the films, 0 = Cafe fire film first, 1 = Utoya film first
  

training <- read.csv("study2_trainingdata.csv", header = TRUE) 

#convert variables to factors - dataset: training
training$condition <- factor(training$condition, levels = c(0,1), labels = c("with tool", "without tool"))
training$filmorder <- factor(training$filmorder, levels = c(0,1), labels = c("cafefire first", "Utoya first"))
training$filmnr <- training$time
training$film <- factor(training$time, levels = c(1,2,3,4,5,6), labels = c("Robert M", "Katrina", "Tsunami", "Boston Marathon", "Koninginnedag Apeldoorn", "mishandeling Eindhoven"))

########## study2_intrusion.csv   
# File with intruction data in wide format
# Data was originally taken from the file newdatabetter2_newthemenums.xlsx - sheet Intrusions
#
# data fields
#
#1 ss: participant ID number
#2 condition : experimental condition, 0 = with tool, 1 = without tool
#3 numIntrusions : How often have you had intrusive memories of one of the films from the study last week?
#4 about1 : Which film or subject was the intrusive memory? (film1)
#5 about2 : Which film or subject was the intrusive memory? (film2)
#6 about3 : Which film or subject was the intrusive memory? (film3)
#7 realness1 : To what extent did the intrusion feel lively / clear (as if you saw it before you)? (0-100%: 0% is not at all, 100% is very strong) (film1)
#8 realness2 : To what extent did the intrusion feel lively / clear (as if you saw it before you)? (0-100%: 0% is not at all, 100% is very strong) (film2)
#9 realness3 : To what extent did the intrusion feel lively / clear (as if you saw it before you)? (0-100%: 0% is not at all, 100% is very strong) (film3)
#10 distress1 : To what extent did you feel distress / alarmed by the intrusive memory? (0-100%: 0% is not at all, 100% is very strong) (film1)
#11 distress2 : To what extent did you feel distress / alarmed by the intrusive memory? (0-100%: 0% is not at all, 100% is very strong) (film2)
#12 distress3 : To what extent did you feel distress / alarmed by the intrusive memory? (0-100%: 0% is not at all, 100% is very strong) (film3)

intrusion<- read.csv("study2_intrusion.csv")
intrusion$condition <- factor(intrusion$condition, levels = c(0,1), labels = c("without tool", "with tool"))
intrusion$realnessMax <-apply(intrusion[, 7:9], 1, max, na.rm=TRUE)
intrusion$realnessMax[is.infinite(intrusion$realnessMax)] <- NA
intrusion$realnessMax <- intrusion$realnessMax *100
intrusion$distressMax <-apply(intrusion[, 10:12], 1, max, na.rm=TRUE)
intrusion$distressMax[is.infinite(intrusion$distressMax)] <- NA
intrusion$distressMax <- intrusion$distressMax *100

##################################################################### FUNCTIONS #####################################

compareModelpre_post <- function(d, dvname, t) 
  {

  # compare the following mulitlevel models
  #  model0: random intercept model, 
  #  model1: model0 + time as fixed effect
  #  model2: model1 + condition as fixed effect
  #  model3: model2 + time & condition as two-way interaction effect
  # d : dataframe
  # dvname : name of the dependent variable (string)
  # t: text to describe the dependent variable for the reader
  
 
  d$dv <- d[, dvname]
  model0 <- lme (dv~ 1, random = ~1|ss, data = d, method = "ML" , na.action = na.exclude, correlation =corSymm(0, form=~1|ss)) 
  model1 <- update(model0, .~. + time)
  model2 <- update(model1, .~. + condition)
  model3 <- update(model2, .~. + condition:time)

 
  cat("\n###########Analysing multilevel models for the dependent variable: ", t ,"\n")
  cat("\nResults of  model 0 which includes on participants as a random intercept\n")
  print(summary(model0))
  cat("\nResult of model 1, which extends model 0 by including time (pre/post) as fixed effect\n")
  print(summary(model1))
 
  cat("\nResult of model 2, which extends model 1 by including condition (with tool/without tool) as fixed effect\n")
  print(summary(model2))
  cat("\nResult of model 3, which extends model 2 by including the two-way interaction between time and condition as fixed effect\n")
  print(summary(model3))

  cat("\nComparing models \n")
  print(anova(model0, model1, model2, model3))
  cat("\n\n 95%CI intervals for model1 (if possible).\n")
  print(intervals(model1))
}


compare_cond <- function(d, dvname, t) 
{
  
  # compare the following mulitlevel models
  #  model0: random intercept model, 
  #  model1: model0 + condition as fixed effect
  # d : dataframe
  # dvname : name of the dependent variable (string)
  # t: text to describe the dependent variable for the reader
  
  
  d$dv <- d[, dvname]
  model0 <- lme (dv~ 1, random = ~1|ss, data = d, method = "ML" , na.action = na.exclude) 
  model1 <- update(model0, .~. + condition)
  
  cat("\nComparing models without (model0) or with condition (model1) as fixed factor on dependent variable: ", t ,"\n")
  print(anova(model0, model1))
  i<-intervals(model0)
  cat("\n\n Fixed intercept Mean = ",i$fixed[2], ", 95% CI[", i$fixed[1], ", ", i$fixed[3], "].\n")
  
}


ICC_explain <- function(m, t)
{ 
  #m: data frame of rating
  #t: text with measure for reader
  
  cat("\nInterclass correlation between 2 coders for the measure: ", t, " (Average_raters_absolute ICC1k).\n")
  ICC(m)
  
}


row_table4 <- function(x_pre,x_post, t)
{
  # compare measure from prepostwide frame
  #x_pre : pre measurment
  #x_post : post measurement
  #t : description measure
  
  cat("\n## Variable ", t, " pre mean: ", mean(x_pre, na.rm = TRUE), " sd: ", sd(x_pre, na.rm = TRUE), "; post mean: ", mean(x_post, na.rm = TRUE), " sd: ", sd(x_post, na.rm = TRUE),"\n")
  print(t.test(x_pre,x_post, paired = TRUE, na.action = na.exclude))

}

mean_sd <-function(x, t){
  # print the mean and standard deviation
  cat(t," mean: ", mean(x,na.rm=TRUE), " sd: ", sd(x, na.rm=TRUE), "\n") 
  
}


percentage <- function(x,v){
   # x : variable
   # v : value to compare
  
  return(length(x[x==v])/length(x))
  
}

countNA <- function(x){
  # x : variable

  
  return(length(x[is.na(x)]))
  
}

testbetween <-function(x,g)
{
  # x integer data being tested
  # g group
  
  l<-leveneTest(x,g)
  if (l$`Pr(>F)`[1]<.05)
  {
    cat("\nLevene's test shows sign difference between the group variance, therefore  Welch Two Sample t-test conducted\n")
    print(t.test(x~g, na.rm = TRUE,var.equal = FALSE))
  } else
  {
    cat("\nLevene's test shows no sign difference between the group variance, therefore  Two Sample t-test conducted\n")
    print(t.test(x~g, na.rm = TRUE,var.equal = TRUE))
  }
  for (c in levels(prepostwide$condition)) 
  {
    d <- x[g==c]
    cat("Group: ", c)
    cat(" mean: ", mean(d, na.rm = TRUE))
    cat(", sd:", sd(d, na.rm = TRUE),";")
    
  }
}

cat("#################################################### ANALYSES #######################################################")

cat("\n########### Section 3.1.2. Participants ###############\n\n")
mean_sd(prepostwide$age, "Age of participants")
cat("\n\nNumber of participants assigned to the two conditions by gender\n")
table(prepostwide$condition, prepostwide$gender)



cat("\n############ Section 3.2 Analysis & data preparation\n\n")

ICC_explain(data.frame(prepostwide$Score_C, prepostwide$Score_U), "Quality score of appraisals")
ICC_explain(data.frame(prepostwide$numANNOS_U_voor, prepostwide$numANNOS_C_voor),"Number of Appraisals prior to training")
ICC_explain(data.frame(prepostwide$numANNOS_U_na, prepostwide$numANNOS_C_na),"Number of Appraisals in post training measurement")



cat("\n########### Section 3.3.1. Primary outcome measures\n\n")
cat("\n Quality of appraisals \n")
my_lm<-lm(Score_mean~condition, data = prepostwide)
summary(my_lm)

cat("\n\nNumber and length of appraisals and Results of table 2- Multilevel analysis results of the primary outcome measures\n\n")
compareModelpre_post(prepostlong,"numANNOS_mean", "Number of appraisals") 
compareModelpre_post(prepostlong,"wordcount", "Word count") 




cat("\n############ Section 3.3.2 Secondary outcome measures &  Results of table 3- Multilevel analyses results PANAS\n\n")
compareModelpre_post(prepostlong,"PA_total", "Positive affect (PANAS)") 
compareModelpre_post(prepostlong,"NA_total", "Negative affect (PANAS)") 

cat("######## Results for Table 4 - Positive affect items that showed decline over time (i.e. pre- to post-training)")

row_table4(prepostwide$p3_voor, prepostwide$p3_na, "Excited")
row_table4(prepostwide$p5_voor, prepostwide$p5_na, "Strong")
row_table4(prepostwide$p12_voor, prepostwide$p12_na, "Alert")
row_table4(prepostwide$p17_voor, prepostwide$p17_na, "Attentive")
row_table4(prepostwide$p19_voor, prepostwide$p19_na, "Active")

cat("\n\n#### Behavioral during training\n\n")

cat("\n Figure 3 has been saved as file Fig3.png")
png(filename="Fig3.png")
line <- ggplot(training, aes(filmnr, numthemes, linetype = condition))
line + stat_summary(fun.y =mean, geom = "point") + stat_summary(fun.y = mean, geom = "line", aes(group = condition))+ labs(x="Time", y= "Number of Themes")+ scale_color_manual("Condition", labels = c("With tool", "Without tool"), values= c("red", "blue"))
print(line)
dev.off

cat("\n\nResult for Table 5 - results of the quasi-Poisson multilevel analysis on number of themes used during training\n\n")


m<-glmmPQL(numthemes~ filmnr + condition + condition:filmnr, data =training,random= ~1|ss, family = c("quasipoisson") , na.action = na.exclude, correlation =corAR1())
summary(m) 


cat("\n##Simple effect analaysis by fixing film number\n")
for (i in c(0:5))
{
  cat("\nResults for only film number ",i,"\n\n")
  conditiondata1 <-subset(training, filmnr == i)
  Model1 <-glmmPQL(numthemes ~ condition, data =conditiondata1, random= ~1|ss, family = c("poisson"), na.action = na.exclude, correlation =corAR1())
  print(summary(Model1))
}


cat("\n##Simple effect analyses by fixing condition\n")
cat("\nResults for only the with tool condition\n\n")
conditiondata1 <-subset(training, condition == "with tool")
Model1 <-glmmPQL(numthemes ~ filmnr, data =conditiondata1, random= ~1|ss, family = c("poisson"), na.action = na.exclude, correlation =corAR1())
summary(Model1)

cat("\nResults for only the without tool condition\n\n")
conditiondata2 <-subset(training, condition == "without tool")
Model1 <- glmmPQL (numthemes ~ filmnr, random = ~1|ss, data = conditiondata2, family = c("poisson"), na.action = na.exclude, correlation =corAR1()) 
summary(Model1)


cat("\n\n####### Instruction compliance\n\n")
mean_sd(prepostwide$meeleven_voor, "Sympathize in pre-measurment")
mean_sd(prepostwide$meeleven_na, "Sympathize in post-measurment")

cat("\nExamining fixed intercept (mean rating and 95% CI) for Sympathize\n")
model0 <- lme (sympathize~ 1, random = ~1|ss, data = prepostlong, method = "ML" , na.action = na.exclude, correlation =corSymm(0, form=~1|ss)) 
i<-intervals(model0)
cat(i$fixed[1])

cat("\nPercentage seen film during pre-measurement ",percentage(prepostwide$seen_voor, 'no'))
cat("\nPercentage seen film during post measurement ",percentage(prepostwide$seen_na, 'no'))

compare_cond(prepostlong,"attentive", "Percentage of time spent paying attention")
compare_cond(prepostlong,"distracted", "Percentage of time being distracted")
compare_cond(prepostlong,"active", "Percentage of time appraising")
compare_cond(prepostlong,"supress", "Percentage of time using suppression")

cat("\n\n########### Intrusion\n\n")
cat("Participants completing and submitting intrusion questionnaire is  ", length(intrusion$numIntrusions) - countNA(intrusion$numIntrusions), 
    "(", 1-countNA(intrusion$numIntrusions) / length(intrusion$numIntrusions),"%)\n")
cat("Number of participants that reported 1 or more intrusions: ", length(intrusion$numIntrusions[intrusion$numIntrusions >0])-countNA(intrusion$numIntrusions))


cat("\n\nTest for group difference on number intrusion reported\n")
testbetween(intrusion$numIntrusions, intrusion$condition)
cat("\n\nTest for group difference on maximum amount of experienced realness (vividness) reported with these intrusions.\n")
testbetween(intrusion$realnessMax, intrusion$condition)
cat("\n\nTest for group difference on maximum amount of experienced distress reported with these intrusions.\n")
testbetween(intrusion$distressMax, intrusion$condition)



cat("\n\n################################### End of analysis for study 2.\n")

######### stop redireting output.
sink()

cat("\n\nOutput of the analysis can be found back in file output-study2.txt")
